@@ -37,11 +37,11 @@ class DAVResponse:
         log.debug("response headers: " + str(self.headers))
         log.debug("response status: " + str(self.status))
 
-        ## OPTIMIZE TODO: if content-type is text/xml, we could eventually do
-        ## streaming into the etree library rather than first read the whole
-        ## content into a string.  (the line below just needs to be moved to
-        ## the relevant if-pronges below)
         self._raw = response.content
+        
+        ## TODO: this if/else/elif could possibly be refactored, or we should
+        ## consider to do streaming into the xmltree library as originally
+        ## intended.  It only makes sense for really huge payloads though.
         if (self.headers.get('Content-Type', '').startswith('text/xml') or
             self.headers.get('Content-Type', '').startswith('application/xml')):
             try:
@@ -67,9 +67,12 @@ class DAVResponse:
             ## Logic here was moved when refactoring
             pass
         else:
-            ## probably content-type was not given, i.e. iCloud does not seem to include those
-            if 'Content-Type' in self.headers:
-                log.error("unexpected content type from server: %s. %s" % (self.headers['Content-Type'], error.ERR_FRAGMENT))
+            ## Probably no content type given (iCloud).  Some servers
+            ## give text/html as the default when no content is
+            ## delivered or on errors (ref
+            ## https://github.com/python-caldav/caldav/issues/142).
+            ## TODO: maybe just remove all of the code above in this if/else and let all
+            ## data be parsed through this code.
             try:
                 self.tree = etree.XML(self._raw, parser=etree.XMLParser(remove_blank_text=True))
             except:
@@ -130,10 +133,15 @@ class DAVResponse:
 
     def validate_status(self, status):
         """
-        status is a string like "HTTP/1.1 404 Not Found".
-        200, 207 and 404 are considered good statuses.
+        status is a string like "HTTP/1.1 404 Not Found".  200, 207 and
+        404 are considered good statuses.  The SOGo caldav server even
+        returns "201 created" when doing a sync-report, to indicate
+        that a resource was created after the last sync-token.  This
+        makes sense to me, but I've only seen it from SOGo, and it's
+        not in accordance with the examples in rfc6578.
         """
         if (' 200 ' not in status and
+            ' 201 ' not in status and
             ' 207 ' not in status and
             ' 404 ' not in status):
             raise error.ResponseError(status)
@@ -269,7 +277,7 @@ class DAVClient:
     low-level operations towards the caldav server.
 
     Unless you have special needs, you should probably care most about
-    the __init__ and principal methods.
+    the constructor (__init__), the principal method and the calendar method.
     """
     proxy = None
     url = None
@@ -316,6 +324,9 @@ class DAVClient:
 
         self.username = username
         self.password = password
+        ## I had problems with passwords with non-ascii letters in it ...
+        if hasattr(self.password, 'encode'):
+            self.password = self.password.encode('utf-8')
         self.auth = auth
         # TODO: it's possible to force through a specific auth method here,
         # but no test code for this.
@@ -340,15 +351,28 @@ class DAVClient:
         return self._principal
 
     def calendar(self, **kwargs):
-        """
-        Returns a newly initiated calendar object.
+        """Returns a calendar object.
 
         Typically, an URL should be given as a named parameter (url)
+
+        No network traffic will be initiated by this method.
+
+        If you don't know the URL of the calendar, use
+        client.principal().calendar(...) instead, or
+        client.principal().calendars()
         """
         return Calendar(client=self, **kwargs)
 
     def check_dav_support(self):
-        response = self.options(self.url)
+        try:
+            ## SOGo does not return the full capability list on the caldav
+            ## root URL, and that's OK according to the RFC ... so apparently
+            ## we need to do an extra step here to fetch the URL of some
+            ## element that should come with caldav extras.
+            ## Anyway, packing this into a try-except in case it fails.
+            response = self.options(self.principal().url)
+        except:
+            response = self.options(self.url)
         return response.headers.get('DAV', None)
 
     def check_cdav_support(self):
@@ -496,8 +520,10 @@ class DAVClient:
             method, url, data=to_wire(body),
             headers=combined_headers, proxies=proxies, auth=auth,
             verify=self.ssl_verify_cert, cert=self.ssl_cert, stream=False) ## TODO: optimize with stream=True maybe
+        log.debug("server responded with %i %s" % (r.status_code, r.reason))
         response = DAVResponse(r)
 
+
         # If server supports BasicAuth and not DigestAuth, let's try again:
         if response.status == 401 and self.auth is None and auth is not None:
             auth = requests.auth.HTTPBasicAuth(self.username, self.password)
