@@ -4,6 +4,10 @@
 """
 A "DAV object" is anything we get from the caldav server or push into the
 caldav server, notably principal, calendars and calendar events.
+
+(This file has become huge and will be split up prior to the next
+release.  I think it makes sense moving the CalendarObjectResource
+class hierarchy into a separate file)
 """
 
 import vobject
@@ -332,12 +336,12 @@ class CalendarSet(DAVObject):
 
     def calendar(self, name=None, cal_id=None):
         """
-        The calendar method will return a calendar object.  It will not
-        initiate any communication with the server.
+        The calendar method will return a calendar object.  If it gets a cal_id
+        but no name, it will not initiate any communication with the server
 
         Parameters:
          * name: return the calendar with this name
-         * cal_id: return the calendar with this calendar id
+         * cal_id: return the calendar with this calendar id or URL
 
         Returns:
          * Calendar(...)-object
@@ -352,8 +356,15 @@ class CalendarSet(DAVObject):
         if not cal_id and not name:
             return self.calendars()[0]
 
+        if str(cal_id).startswith(str(self.client.url)):
+            url = self.client.url.join(cal_id)
+        elif isinstance(cal_id, URL):
+            url = self.url.join(cal_id)
+        else:
+            url = self.url.join(quote(cal_id) + '/')
+
         return Calendar(self.client, name=name, parent=self,
-                        url=self.url.join(quote(cal_id)+'/'), id=cal_id)
+                        url=url, id=cal_id)
 
 class Principal(DAVObject):
     """
@@ -423,7 +434,13 @@ class Principal(DAVObject):
     @property
     def calendar_home_set(self):
         if not self._calendar_home_set:
-            self.calendar_home_set = self.get_property(cdav.CalendarHomeSet())
+            calendar_home_set_url = self.get_property(cdav.CalendarHomeSet())
+            ## owncloud returns /remote.php/dav/calendars/tobixen@e.email/
+            ## in that case the @ should be quoted.  Perhaps other
+            ## implentations returns already quoted URLs.  Hacky workaround:
+            if '@' in calendar_home_set_url and not '://' in calendar_home_set_url:
+                calendar_home_set_url = quote(calendar_home_set_url)
+            self.calendar_home_set = calendar_home_set_url
         return self._calendar_home_set
 
     @calendar_home_set.setter
@@ -475,7 +492,6 @@ class Principal(DAVObject):
         for attendee in attendees:
             caldavobj.add_attendee(attendee, no_default_parameters=True)
 
-        import pdb; pdb.set_trace()
         response = self.client.post(outbox.url, caldavobj.data, headers={'Content-Type': 'text/calendar; charset=utf-8'})
         return response.find_objects_and_props()
 
@@ -625,7 +641,7 @@ class Calendar(DAVObject):
 
     def calendar_multiget(self, event_urls):
         """
-		get multiple events' data
+        get multiple events' data
         @author mtorange@gmail.com
         @type events list of Event
         """
@@ -633,7 +649,7 @@ class Calendar(DAVObject):
         prop = dav.Prop() + cdav.CalendarData()
         root = cdav.CalendarMultiGet() + prop + [dav.Href(value=u.path) for u in event_urls]
         response = self._query(root, 1, 'report')
-        results = self._handle_prop_response(response=response, props=[cdav.CalendarData()])
+        results = response.expand_simple_props([cdav.CalendarData()])
         for r in results:
             rv.append(
                 Event(self.client, url=self.url.join(r), data=results[r][cdav.CalendarData.tag], parent=self))
@@ -1058,10 +1074,13 @@ class Calendar(DAVObject):
 
 class ScheduleMailbox(Calendar):
     """
-    RFC6638
-    TODO: This is a bit incorrect, a ScheduleMailbox is a collection,
-    but not really a calendar.  We should create a common base class
-    for ScheduleMailbox and Calendar eventually.
+    RFC6638 defines an inbox and an outbox for handling event scheduling.
+
+    TODO: As ScheduleMailboxes works a bit like calendars, I've chosen
+    to inheritate the Calendar class, but this is a bit incorrect, a
+    ScheduleMailbox is a collection, but not really a calendar.  We
+    should create a common base class for ScheduleMailbox and Calendar
+    eventually.
     """
     def __init__(self, client=None, principal=None, url=None):
         """
@@ -1212,8 +1231,7 @@ class CalendarObjectResource(DAVObject):
         * An email address prepended with "mailto:"
         * An email address without the "mailto:"-prefix
         * A two-item tuple containing a common name and an email address
-        * (not supported, but planned: an ical text line starting with the 
-          word "ATTENDEE")
+        * (not supported, but planned: an ical text line starting with the word "ATTENDEE")
 
         Any number of attendee parameters can be given, those will be used
         as defaults unless no_default_parameters is set to True:
@@ -1243,6 +1261,9 @@ class CalendarObjectResource(DAVObject):
                 attendee_obj = vCalAddress(attendee)
             elif '@' in attendee and not ':' in attendee and not ';' in attendee:
                 attendee_obj = vCalAddress('mailto:' + attendee)
+        else:
+            error.assert_(False)
+            attendee_obj = vCalAddress()
 
         ## TODO: if possible, check that the attendee exists
         ## TODO: check that the attendee will not be duplicated in the event.
@@ -1290,7 +1311,7 @@ class CalendarObjectResource(DAVObject):
         self.change_attendee_status(partstat=partstat)
         self.get_property(cdav.ScheduleTag(), use_cached=True)
         try:
-            Event(self.client, data=self.data, parent=calendar, id=self.id).save()
+            calendar.save_event(self.data)
         except Exception as some_exception:
             ## TODO - TODO - TODO
             ## RFC6638 does not seem to be very clear (or
@@ -1363,8 +1384,12 @@ class CalendarObjectResource(DAVObject):
                     obj.uid.value = id
                     break
         if path is None:
-            path = quote(id) + ".ics"
+            ## See https://github.com/python-caldav/caldav/issues/143 for the rationale behind double-quoting slashes
+            ## TODO: should try to wrap my head around issues that arises when id contains weird characters.  maybe it's
+            ## better to generate a new uuid here, particularly if id is in some unexpected format.
+            path = quote(id.replace('/', '%2F')) + ".ics"
         path = self.parent.url.join(path)
+        ## SECURITY TODO: we should probably have a check here to verify that no such object exists already
         r = self.client.put(path, data,
                             {"Content-Type": 'text/calendar; charset="utf-8"'})
 
@@ -1396,9 +1421,12 @@ class CalendarObjectResource(DAVObject):
             return
 
         ical_obj = self._icalendar_object()
-        ## TODO: can attendee be a single value?
-        for attendee_line in ical_obj['attendee']:
-            if str(attendee_line).replace('mailto:','') == str(attendee).replace('mailto:',''):
+        attendee_lines = ical_obj['attendee']
+        if isinstance(attendee_lines, str):
+            attendee_lines = [attendee_lines]
+        strip_mailto = lambda x: str(x).replace('mailto:','').lower()
+        for attendee_line in attendee_lines:
+            if strip_mailto(attendee_line) == strip_mailto(attendee):
                    attendee_line.params.update(kwargs)
                    cnt += 1
         if not cnt:
@@ -1428,6 +1456,15 @@ class CalendarObjectResource(DAVObject):
         path = self.url.path if self.url else None
 
         if no_overwrite or no_create:
+            ## SECURITY TODO: path names on the server does not
+            ## necessarily map cleanly to UUIDs.  We need to do quite
+            ## some refactoring here to ensure all corner cases are
+            ## covered.  Doing a GET first to check if the resource is
+            ## found and then a PUT also gives a potential race
+            ## condition.  (Possibly the API gives no safe way to ensure
+            ## a unique new calendar item is created to the server without
+            ## overwriting old stuff or vice versa - it seems silly to me
+            ## to do a PUT instead of POST when creating new data).
             if not self.id:
                 try:
                     self.id = self.vobject_instance.vevent.uid.value
