@@ -14,7 +14,7 @@
 incompatibility_description = {
     'no_expand':
         """Server may throw errors when asked to do a expanded date search""",
-    
+
     'no_recurring':
         """Server is having issues with recurring events and/or todos. """
         """date searches covering recurrances may yield no results, """
@@ -22,10 +22,13 @@ incompatibility_description = {
 
     'no_recurring_expandation':
         """Server will not expand recurring events""",
-    
+
     'no_recurring_todo':
         """Recurring events are supported, but not recurring todos""",
-    
+
+    'no_recurring_todo_expand':
+        """Recurring todos aren't expanded""",
+
     'no_scheduling':
         """RFC6833 is not supported""",
 
@@ -34,7 +37,7 @@ incompatibility_description = {
         """(or without pre-defined calendars at all)""",
 
     'non_existing_calendar_found':
-        """Server will not yield a 404 if existing a random calendar URL """
+        """Server will not yield a 404 when accessing a random calendar URL """
         """(perhaps the calendar will be automatically created on access)""",
 
     'no_freebusy_rfc4791':
@@ -75,7 +78,16 @@ incompatibility_description = {
         """Server will not accept calendar object resources without an UID""",
 
     'no_sync_token':
-        """RFC6578 is not supported""",
+        """RFC6578 is not supported, things will break if we try to do a sync-token report""",
+
+    'time_based_sync_tokens':
+        """The sync token is typically a time stamp, and we need to sleep a """
+        """second in the test code to get things right""",
+
+    'fragile_sync_tokens':
+        """Every now and then (or perhaps always), more content than expected """
+        """will be returned on a simple sync request.  Possibly a race condition """
+        """if the token is timstamp-based?""",
 
     'propfind_allprop_failure':
         """The propfind test fails ... """
@@ -91,6 +103,13 @@ incompatibility_description = {
     'vtodo_datesearch_nodtstart_task_is_skipped':
         """date searches for todo-items will not find tasks without a dtstart""",
 
+    'vtodo_no_due_infinite_duration':
+        """date search will find todo-items without due if dtstart is """
+        """before the date search interval.  I didn't find anything explicit """
+        """in The RFC on this (), but an event should be considered to have 0 """
+        """duration if no dtend is set, and most server implementations seems to """
+        """treat VTODOs the same""",
+
     'no_todo_on_standard_calendar':
         """Tasklists can be created, but a normal calendar does not support tasks""",
 
@@ -104,9 +123,6 @@ incompatibility_description = {
     'object_by_uid_is_broken':
         """calendar.object_by_uid(uid) does not work""",
 
-    'fragile_sync_tokens':
-        """Every now and then, all calendar content will be returned on a simple sync request""",
-
     'no_mkcalendar':
         """mkcalendar is not supported""",
 
@@ -192,12 +208,11 @@ bedework = [
 baikal = [
     ## date search on todos does not seem to work
     ## (TODO: do some research on this)
-    'notododatesearch',
+    'no_todo_datesearch',
 
     ## extra features not specified in RFC5545
-    "calendarorder",
-    "calendarcolor"
-
+    "calendar_order",
+    "calendar_color"
 ]
 
 ## See comments on https://github.com/python-caldav/caldav/issues/3
@@ -211,7 +226,7 @@ icloud = [
     'no_recurring',
     'propfind_allprop_failure',
     'object_by_uid_is_broken'
-    ]
+]
 
 davical = [
     #'nofreebusy', ## for old versions 
@@ -226,3 +241,17 @@ google = [
     'no_todo',
     'no_recurring_expandation'
 ]
+
+sogo = [
+    'no_journal',
+    'no_freebusy_rfc4791', ## https://www.sogo.nu/bugs/view.php?id=5282
+    "time_based_sync_tokens", ## Left a note on https://www.sogo.nu/bugs/view.php?id=5163
+    "no_expand", ## https://www.sogo.nu/bugs/view.php?id=3065
+    "vtodo_datesearch_nodtstart_task_is_skipped",
+]
+
+nextcloud = [
+    'no_sync_token',
+    'no_recurring_todo',
+    'no_recurring_todo_expand',
+]
